@@ -1,6 +1,6 @@
 package WebDAO::Test;
 
-#$Id: Test.pm 852 2010-10-17 18:57:02Z zag $
+#$Id$
 
 =head1 NAME
 
@@ -250,6 +250,12 @@ sub _init {
 
 }
 
+sub response {
+    my $self = shift;
+    my $res = shift || return;
+    $self->print( $res->{data} );
+}
+
 sub print {
     my $self = shift;
     my $out_ref = $self->{ctr};
